from django.apps import AppConfig

class DjangoCommandsSuiteConfig(AppConfig):
   default_auto_field = 'django.db.models.BigAutoField'
   name = 'django_commands_suite'
   verbose_name = "Django Commands Suite"
