from django.urls import path
from . import views

urlpatterns = [
   path("dcs_terminal/", views.terminal_page, name="dcs_terminal"),
   #path("dcs_terminal/run/", views.run_command, name="dcs_run_command"),
]
